#!/bin/sh

# Parse le dico eole
. ParseDico

# Recuperation des mots de passe et login
eval `cat  /usr/share/sentinelle/password `

nom_dns=$nom_machine"."$nom_academie".fr"
host $nom_dns
if [ $? -ne 0 ] ; then
	nom_dns=$adresse_ip_eth0
fi


WWWHOME=/var/www/sentinelle
SentinelleDir=/usr/share/sentinelle-server
InstallDir=/usr/share/sentinelle
ConfDir=/etc/sentinelle


echo -n "Mise à jour de sentinelle-server            : "
if [ -d $SentinelleDir ] ; then
	rm -rf $SentinelleDir/*
else
	mkdir $SentinelleDir
fi
cp -rf $InstallDir/sentinelle/* $SentinelleDir


if [ -d $ConfDir ] ; then
	#cp -r $ConfDir/*  $SentinelleDir/conf/local
	# Au lieu de recopier l'intégraliter du dossier local (/etc/sentinelle)
	# on fait un lien symbolique
	# Avantage : Lors du modif local, un restart de sentinelle suffit
	# 	     il n'est plus nécessaire de faire un reconf-sentinelle
	rm -rf $SentinelleDir/conf/local
        ln -s /etc/sentinelle $SentinelleDir/conf/local
fi

echo " OK"

echo -n "Mise à jour de la partie web dans /var/www  : "

if [ ! -d $WWWHOME ] ; then
	mkdir $WWWHOME
else
	rm -rf $WWWHOME/*
fi

cp -R $InstallDir/web/* $WWWHOME

echo " OK"

echo -n "Mise à jour des certificats                 : "
cp -f /etc/ssl/sentinelle/serveur.ks $SentinelleDir/security/serveur.ks
echo " OK"

# ========================================================
# Sentinelle-web
# Initialisation du dossier utilisé pour sentinelle-web
if [ ! -e $ConfDir/web/map ] ; then
	mkdir -p $ConfDir/web/map
	mkdir -p $ConfDir/web/images
	mkdir -p $ConfDir/web/vues
	mkdir -p $ConfDir/web/perspectives
fi

# Maj des images
cp -rf $WWWHOME/picto/* $ConfDir/web/images

# Maj des vues/perspectives par défaut
cp -rf $InstallDir/web-defaults/vues/*.vue $ConfDir/web/vues
cp -rf $InstallDir/web-defaults/perspectives/*.dim $ConfDir/web/perspectives


if [ ! -e $ConfDir/local.conf ] ; then
  cp $InstallDir/conf/local.conf $ConfDir/local.conf
fi

echo "
<?xml version='1.0' encoding='UTF-8'?>
<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Strict//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd'>
<html xmlns='http://www.w3.org/1999/xhtml'>
<head>
        <meta http-equiv='refresh' content='0; url=https://$sentinelleweb_dns:$tomcat_port/SentinelleOnAir' />
</head>
</html> " > $WWWHOME/index.html


# Regénère le keystore pour tomcat
DEFAULTPASS="changeit"
/usr/lib/jvm/java-6-sun/jre/bin/keytool -genkey -alias "sentinelleweb_dns" -keypass $DEFAULTPASS -storepass $DEFAULTPASS -dname "CN=SentinelleWeb@$nom_academie, OU=$nom_academie, O=GOUV, L=, S=, C=FR"   -keyalg RSA -keystore /etc/ssl/sentinelle/tomcat.ks  >/dev/null



#===========================================================

# Génération de l'include zephir
echo -n "Mise à jour  des profiles                   : "
INC_ZEPHIR="$SentinelleDir/scripts/inc_connect.py"
echo "sUserName='$ZEPHIR_LOGIN'"    >   $INC_ZEPHIR
echo "sPasswd='$ZEPHIR_PASSWORD'"  >>   $INC_ZEPHIR
echo "sIp='$adresse_zephir:7080'" >>   $INC_ZEPHIR
echo "sUrlZephir='https://'+ sUserName +':'+ sPasswd + '@' + sIp" >>   $INC_ZEPHIR

# Generation du mot de passe d'accès a la base sentinelle =========
echo "pooldb_mysql.user=$MYSQL_SENTINELLE_LOGIN"        >  $SentinelleDir/conf/db.conf
echo "pooldb_mysql.password=$MYSQL_SENTINELLE_PWD"      >> $SentinelleDir/conf/db.conf

echo "<?
define(\"DB_HOST\",\"localhost\");
define(\"DB_NAME\", \"persistance\");
define(\"DB_USER\",\"$MYSQL_SENTINELLE_LOGIN\");
define(\"DB_PASSWORD\",\"$MYSQL_SENTINELLE_PWD\");

//Sentinelle Web
define(\"SENTINELLEWEB_DIR\",\"$ConfDir/web\");
define(\"ALLOW_IP\",\"127.0.0.1,$adresse_ip_eth0\");
?>" >  $WWWHOME/classes/inc.php

cp $WWWHOME/classes/inc.php  $WWWHOME/interfaces/inc.php

echo " OK"

if [ ! -e $ConfDir/web/map/etabs.gps ] ; then
	echo "============================================"
	echo "ATTENTION"
  echo "   Le fichier de coordonnées des établissements n'éxiste pas"
  echo "   Veuillez vous munir d'une clef googleMap "
  echo "   http://code.google.com/intl/fr/apis/maps/signup.html"
  echo "   et lancer les commandes suivantes"
  echo ""
  echo "   cd /usr/share/sentinelle-server/scripts"
  echo "   python RecupGPSEtabsFromZephir.py"
  echo "==========================================="
fi

#if [ ! -e $ConfDir/client/_client/carte.png ] ; then
#	echo ""
#	echo "ATTENTION : La carte n'éxiste pas"
#fi

cd $DOSSIER
# ===================================================================================
