#!/bin/bash

############################
# sentinelle.sh
# instructions spécifiques au module sentinelle
############################

# ========================================
# CHANGE
#
# 14/09/07 : CLEON
#    AJOUT url_data=https://$adresse_ip_eth0/sentinelle/classes/CData.php dans le profile par défaut
#    AJOUT sed -i $EXPR /var/www/sentinelle/classes/inc.php après la copie du repertoire web
#		afin de modifier le mot de passe sentinelle d'accès à la base

# Appel Bibliothèque
. ParseDico
. /usr/share/eole/FonctionsEoleNg

InstallDir=/usr/share/sentinelle
PasswordFile=/usr/share/sentinelle/password
WWWHOME=/var/www/sentinelle
SentinelleDir=/usr/share/sentinelle-server
ConfDir=/etc/sentinelle

# prise en compte des paramètres réseau
/etc/init.d/networking restart

# installation des runtimes java
dpkg -l sun-java6-jre 2>/dev/null | grep -q ^ii
if [ $? -ne 0 ]
then
	echo "Mise à jour de la base de paquets..."
	Query-Auto > /dev/null
	echo "Installation des librairies java..."
	apt-get install -y -f sun-java6-jre
	if [ $? -ne 0 ]
	then
		echo
		EchoRouge "Les runtime java 6 sont nécessaires au fonctionnement de sentinelle !"
		echo
		exit 1
	fi
fi

REP="n"
if [ -e $PasswordFile ] ; then
	echo -n "Les mots passes sont déjà définis, voulez-vous les changer (o/n) ? "
	read REP
else
	REP="o"
fi

if [ $REP == "o" -o  $REP == "oui" ] ; then
	stty -echo
	# saisie du mot de passe de l'administrateur mysql
	read -p "Mot de passe root mysql         ? " MYSQL_ROOT_PWD
	echo
	read -p "Confirmation du mot de passe    ? " MYSQL_ROOT_PWD2
	echo
	while [ "$MYSQL_ROOT_PWD" != "$MYSQL_ROOT_PWD2" ]
	do
		read -p "Mot de passe root mysql         ? " MYSQL_ROOT_PWD
		echo
		read -p "Confirmation du mot de passe    ? " MYSQL_ROOT_PWD2
		echo
	done
	# saisie du mot de passe de l'administrateur mysql
	read -p "Mot de passe sentinelle (mysql) ? " MYSQL_SENTINELLE_PWD
	echo
	read -p "Confirmation du mot de passe    ? " MYSQL_SENTINELLE_PWD2
	echo
	while [ "$MYSQL_SENTINELLE_PWD" != "$MYSQL_SENTINELLE_PWD2" ]
	do
		read -p "Mot de passe sentinelle (mysql) ? " MYSQL_SENTINELLE_PWD
		echo
		read -p "Confirmation du mot de passe    ? " MYSQL_SENTINELLE_PWD2
		echo
	done
	# Accès à zephir
	stty echo
	echo "Acces a zephir"
	echo -n "  login : " ; read ZEPHIR_LOGIN
	stty -echo
	echo -n "  mot de passe : " ; read ZEPHIR_PASSWORD
	echo ""
	stty echo


else
	eval `cat  $PasswordFile`
fi

## Creation du nouveau mot de passe root
/usr/bin/python /usr/share/eole/mysql_pwd.py $MYSQL_ROOT_PWD

## Sentinelle
if [ ! -f /var/lib/mysql/sentinelle/db.opt ]
then
	if [ -f $InstallDir/sql_structure.sql ]
	then
	   echo -n "Génération de la base Sentinelle            :"
	   mysql -u root --password=$MYSQL_ROOT_PWD < $InstallDir/sql_structure.sql # > /dev/null 2>&1
	   mysql  --user=root --password=$MYSQL_ROOT_PWD -e "SET PASSWORD FOR 'sentinelle'@'localhost' = PASSWORD('$MYSQL_SENTINELLE_PWD');"
	   echo " OK"
	 fi
fi

pushd $InstallDir > /dev/null

INC_ZEPHIR="sentinelle/scripts/inc_connect.py"
echo "sUserName='$ZEPHIR_LOGIN'"    >   $INC_ZEPHIR
echo "sPasswd='$ZEPHIR_PASSWORD'"  >>   $INC_ZEPHIR
echo "sIp='$adresse_zephir:7080'" >>   $INC_ZEPHIR
echo "sUrlZephir='https://'+ sUserName +':'+ sPasswd + '@' + sIp" >>   $INC_ZEPHIR

R=`python sentinelle/scripts/testconnect.py`
if [ "$R" == "0" ] ; then
	echo
	EchoRouge "Impossible de se connecter à Zephir : $adresse_zephir:7080 "
	echo
	exit 1
fi

echo ""
echo -n "Récupération des établissements             :"
python sentinelle/scripts/RecupEtabsClientFromZephir.py
if [ $? -eq 1 ] ; then
	echo
	EchoRouge "Erreur lors de la récupération, vérifiez vos identifiants Zephir "
	echo
	exit 1
fi

L=`cat sentinelle/conf/etabs.txt | wc -l` ; L=`expr $L + 0`
echo " $L établissements récupérés"
#rm -rf $INC_ZEPHIR

#======================================================================================

if [ -d $SentinelleDir ] ; then
	rm -rf $SentinelleDir
fi


#======================================================================================

echo -n "Génération des certificats                  : "

# certificat eole.crt utilisé pour apache
cp -f /etc/apache2/mods-available/ssl.* /etc/apache2/mods-enabled
/etc/init.d/apache2 restart >/dev/null 2>&1


#======================================================================================
if [ ! -d /etc/ssl/sentinelle ] ; then
	mkdir /etc/ssl/sentinelle
else
	rm -rf /etc/ssl/sentinelle/*
fi
KEYTOOL=/usr/lib/jvm/java-6-sun/bin/keytool
SRV_STOREPASS=`pwgen -1`
SRV_KEYPASS=$SRV_STOREPASS
CLT_STOREPASS=`pwgen -1`
CLT_KEYPASS=$CLT_STOREPASS

$KEYTOOL -genkey -alias sentinellesrv -keypass $SRV_KEYPASS -storepass $SRV_STOREPASS -dname "CN=Sentinelle Serveur@$nom_academie, OU=$nom_academie, O=GOUV, L=, S=, C=FR"   -keyalg RSA -keystore /etc/ssl/sentinelle/serveur.ks  >/dev/null
$KEYTOOL -export -alias sentinellesrv -keystore /etc/ssl/sentinelle/serveur.ks -file /etc/ssl/sentinelle/serveur.cert -storepass $SRV_STOREPASS  >/dev/null

DEFAULTPASS="changeit"
$KEYTOOL -genkey -alias "sentinelleweb_dns" -keypass $DEFAULTPASS -storepass $DEFAULTPASS -dname "CN=SentinelleWeb@$nom_academie, OU=$nom_academie, O=GOUV, L=, S=, C=FR"   -keyalg RSA -keystore /etc/ssl/sentinelle/tomcat.ks  >/dev/null


echo " OK"

# Si le répertoire local n'existe pas on le crée
if [ ! -d /etc/sentinelle/client/_client ] ; then
       mkdir -p /etc/sentinelle/client/_client
       LOCALDEPS="/etc/sentinelle/client/local.deps"
       echo "_client/etabs.txt" >  $LOCALDEPS
fi

# ========================================================
# Sentinelle-web
# Initialisation du dossier utilisé pour sentinelle-web
if [ ! -e $ConfDir/web/map ] ; then
	mkdir -p $ConfDir/web/map
	mkdir -p $ConfDir/web/images
	mkdir -p $ConfDir/web/vues
	mkdir -p $ConfDir/web/perspectives
fi

if [ ! -e $confDir/client/_client/etabs.txt ] ; then
	echo "Le fichier de coordonnées des établissements n'existe pas"
	echo -n " Voulez-vous le créer maintenant o/n ? "; read R
	if [ "$R" = "o" -o "$R" = "O" ] ; then
		python sentinelle/scripts/RecupGPSEtabsFromZephir.py

	fi
fi


rm -f $PasswordFile
echo "MYSQL_ROOT_PWD=\"$MYSQL_ROOT_PWD\""               > $PasswordFile
echo "MYSQL_SENTINELLE_LOGIN=\"sentinelle\""            >> $PasswordFile
echo "MYSQL_SENTINELLE_PWD=\"$MYSQL_SENTINELLE_PWD\""   >> $PasswordFile
echo "ZEPHIR_LOGIN=\"$ZEPHIR_LOGIN\""                   >> $PasswordFile
echo "ZEPHIR_PASSWORD=\"$ZEPHIR_PASSWORD\""             >> $PasswordFile
echo "SRV_KEYPASS=$SRV_KEYPASS"				>> $PasswordFile
echo "SRV_STOREPASS=$SRV_STOREPASS"			>> $PasswordFile
echo "CLT_KEYPASS=$CLT_KEYPASS"                         >> $PasswordFile
echo "CLT_STOREPASS=$CLT_STOREPASS"                     >> $PasswordFile

/usr/share/eole/reconf-sentinelle.sh

popd > /dev/null
